==> purpose6-6.8.0-1-x86_64.pkg.tar.zst: usr/lib/cmake/KF6Purpose/KF6PurposeTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF6::Purpose" for configuration "Release"
set_property(TARGET KF6::Purpose APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::Purpose PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Network;KF6::ConfigCore;Qt6::DBus"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF6Purpose.so.6.8.0"
  IMPORTED_SONAME_RELEASE "libKF6Purpose.so.6"
  )

list(APPEND _cmake_import_check_targets KF6::Purpose )
list(APPEND _cmake_import_check_files_for_KF6::Purpose "${_IMPORT_PREFIX}/lib/libKF6Purpose.so.6.8.0" )

# Import target "KF6::PurposeWidgets" for configuration "Release"
set_property(TARGET KF6::PurposeWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::PurposeWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;KF6::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF6PurposeWidgets.so.6.8.0"
  IMPORTED_SONAME_RELEASE "libKF6PurposeWidgets.so.6"
  )

list(APPEND _cmake_import_check_targets KF6::PurposeWidgets )
list(APPEND _cmake_import_check_files_for_KF6::PurposeWidgets "${_IMPORT_PREFIX}/lib/libKF6PurposeWidgets.so.6.8.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> purpose6-6.10.0-2-x86_64.pkg.tar.zst: usr/lib/cmake/KF6Purpose/KF6PurposeTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF6::Purpose" for configuration "Release"
set_property(TARGET KF6::Purpose APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::Purpose PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Network;KF6::ConfigCore;Qt6::DBus"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF6Purpose.so.6.10.0"
  IMPORTED_SONAME_RELEASE "libKF6Purpose.so.6"
  )

list(APPEND _cmake_import_check_targets KF6::Purpose )
list(APPEND _cmake_import_check_files_for_KF6::Purpose "${_IMPORT_PREFIX}/lib/libKF6Purpose.so.6.10.0" )

# Import target "KF6::PurposeWidgets" for configuration "Release"
set_property(TARGET KF6::PurposeWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::PurposeWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;KF6::I18n;KF6::I18nQml"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF6PurposeWidgets.so.6.10.0"
  IMPORTED_SONAME_RELEASE "libKF6PurposeWidgets.so.6"
  )

list(APPEND _cmake_import_check_targets KF6::PurposeWidgets )
list(APPEND _cmake_import_check_files_for_KF6::PurposeWidgets "${_IMPORT_PREFIX}/lib/libKF6PurposeWidgets.so.6.10.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
